==> xcsoar-6.5.4.tar.bz2: xcsoar-6.5.4/src/Dialogs/Task/Widgets/LineSectorZoneEditWidget.hpp <==
/*
  Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_LINE_ZONE_EDIT_WIDGET_HPP
#define XCSOAR_LINE_ZONE_EDIT_WIDGET_HPP

#include "ObservationZoneEditWidget.hpp"

#include <assert.h>

class LineSectorZone;

class LineSectorZoneEditWidget : public ObservationZoneEditWidget {
  const bool length_editable;

public:
  LineSectorZoneEditWidget(LineSectorZone &oz, bool length_editable);

protected:
  const LineSectorZone &GetObject() const {
    return (const LineSectorZone &)ObservationZoneEditWidget::GetObject();
  }

  LineSectorZone &GetObject() {
    return (LineSectorZone &)ObservationZoneEditWidget::GetObject();
  }

public:
  /* virtual methods from class Widget */
  virtual void Prepare(ContainerWindow &parent,
                       const PixelRect &rc) override;
  virtual bool Save(bool &changed, bool &require_restart) override;
};

#endif

==> xcsoar-6.6.1.tar.bz2: xcsoar-6.6.1/src/Dialogs/Task/Widgets/LineSectorZoneEditWidget.hpp <==
/*
  Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_LINE_ZONE_EDIT_WIDGET_HPP
#define XCSOAR_LINE_ZONE_EDIT_WIDGET_HPP

#include "ObservationZoneEditWidget.hpp"

#include <assert.h>

class LineSectorZone;

class LineSectorZoneEditWidget : public ObservationZoneEditWidget {
  const bool length_editable;

public:
  LineSectorZoneEditWidget(LineSectorZone &oz, bool length_editable);

protected:
  const LineSectorZone &GetObject() const {
    return (const LineSectorZone &)ObservationZoneEditWidget::GetObject();
  }

  LineSectorZone &GetObject() {
    return (LineSectorZone &)ObservationZoneEditWidget::GetObject();
  }

public:
  /* virtual methods from class Widget */
  virtual void Prepare(ContainerWindow &parent,
                       const PixelRect &rc) override;
  virtual bool Save(bool &changed) override;
};

#endif
